summaryrefslogtreecommitdiff
path: root/ft/le-cursor.h
diff options
context:
space:
mode:
authorJohn Esmet <john.esmet@gmail.com>2014-03-02 17:48:24 -0500
committerJohn Esmet <john.esmet@gmail.com>2014-03-02 18:04:37 -0500
commit91cecf38ff33eb10e679a496c21c2b2c7aee68d7 (patch)
tree1ffe9e4b7a55cef026995d5323ccdf09dcfbd870 /ft/le-cursor.h
parentfa02c19d62c8c527be88980ccc09ab40a6480f11 (diff)
downloadmariadb-git-91cecf38ff33eb10e679a496c21c2b2c7aee68d7.tar.gz
fixes #188 Renamed the last brt artifacts to ft_handle. Tried to keep
comments etc sane by not dropping a big sed bomb. Hopefully things make sense from here on out.
Diffstat (limited to 'ft/le-cursor.h')
-rw-r--r--ft/le-cursor.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/ft/le-cursor.h b/ft/le-cursor.h
index eac5a4e5de4..d443666492c 100644
--- a/ft/le-cursor.h
+++ b/ft/le-cursor.h
@@ -104,10 +104,10 @@ PATENT RIGHTS GRANT:
typedef struct le_cursor *LE_CURSOR;
// Create a leaf cursor for a tree (brt) within a transaction (txn)
// Success: returns 0, stores the LE_CURSOR in the le_cursor_result
// Failure: returns a non-zero error number
-int toku_le_cursor_create(LE_CURSOR *le_cursor_result, FT_HANDLE brt, TOKUTXN txn);
+int toku_le_cursor_create(LE_CURSOR *le_cursor_result, FT_HANDLE ft_h, TOKUTXN txn);
// Close and free the LE_CURSOR
void toku_le_cursor_close(LE_CURSOR le_cursor);
@@ -104,10 +104,10 @@ PATENT RIGHTS GRANT:
typedef struct le_cursor *LE_CURSOR;
-// Create a leaf cursor for a tree (brt) within a transaction (txn)
+// Create a leaf cursor for a tree (ft_h) within a transaction (txn)
// Success: returns 0, stores the LE_CURSOR in the le_cursor_result
// Failure: returns a non-zero error number